@@ -33,13 +33,10 @@
 #endif
 
 #include "pages/language/gis-language-page.h"
-#include "pages/region/gis-region-page.h"
 #include "pages/keyboard/gis-keyboard-page.h"
-#include "pages/eulas/gis-eula-pages.h"
 #include "pages/network/gis-network-page.h"
 #include "pages/timezone/gis-timezone-page.h"
 #include "pages/privacy/gis-privacy-page.h"
-#include "pages/software/gis-software-page.h"
 #include "pages/goa/gis-goa-page.h"
 #include "pages/account/gis-account-pages.h"
 #include "pages/password/gis-password-page.h"
@@ -66,15 +63,10 @@ typedef struct {
 
 static PageData page_table[] = {
   PAGE (language, FALSE),
-#ifdef ENABLE_REGION_PAGE
-  PAGE (region,   FALSE),
-#endif /* ENABLE_REGION_PAGE */
   PAGE (keyboard, FALSE),
-  PAGE (eula,     FALSE),
   PAGE (network,  FALSE),
   PAGE (privacy,  FALSE),
   PAGE (timezone, TRUE),
-  PAGE (software, TRUE),
   PAGE (goa,      FALSE),
   PAGE (account,  TRUE),
   PAGE (password, TRUE),
